#include <iostream>
#include <Bpp/Seq.all>

using namespace bpp;
using namespace std;

/* input arguments */
int opt_match;
int opt_mismatch;
int opt_gapopen;
int opt_gapextend;

int main(int argc, char * argv[])
{
  if (argc != 7)
  {
    cerr << " syntax: " << argv[0] << " [SEQ1] [SEQ2] [MATCH] [MISMATCH] [GAPOPEN] [GAPEXTEND]" << endl;
    return 1;
  }

  /* store the two sequences in string format */
  string s1(argv[1]);
  string s2(argv[2]);

  /* read input parameters */
  opt_match = atoi(argv[3]);
  opt_mismatch = atoi(argv[4]);
  opt_gapopen = atoi(argv[5]);
  opt_gapextend = atoi(argv[6]);

  /* create two sequences for Bio++ */
  Sequence* seq1 = new BasicSequence("Sequence 1", s1, &AlphabetTools::DNA_ALPHABET);
  Sequence* seq2 = new BasicSequence("Sequence 2", s2, &AlphabetTools::DNA_ALPHABET);

  /* output input arguments */
  cout << "Sequence 1: " << seq1->toString() << endl;
  cout << "Sequence 2: " << seq2->toString() << endl;
  cout << "Match: " << opt_match << endl;
  cout << "Mismatch: " << opt_mismatch << endl;
  cout << "Gap open: " << opt_gapopen << endl;
  cout << "Gap extend: " << opt_gapextend << endl;

  /* create a simple symmetric scoring matrix */
  SimpleScore a(seq1->getAlphabet(), opt_match, opt_mismatch);

  /* Globally align sequences using affine gaps scheme */
  AlignedSequenceContainer * aligned = bpp::SiteContainerTools::alignNW(*seq1,
                                                                        *seq2,
                                                                        a,
                                                                        opt_gapopen,
                                                                        opt_gapextend);

  /* output alignment */
  int n = aligned->getNumberOfSequences();
  for (int i = 0; i < n; ++i)
  {
    cout << aligned->getSequence(i).toString() << endl;
  }

  return 0;
}
